You are viewing a plain text version of this content. The canonical link for it is here.
Posted to java-dev@axis.apache.org by pi...@apache.org on 2007/03/30 21:24:23 UTC

svn commit: r524243 [16/17] - in /webservices/axis2/trunk/c: axiom/include/ axiom/src/attachments/ axiom/src/om/ axiom/src/parser/libxml2/ axiom/src/soap/ axiom/test/om/ axiom/test/soap/ guththila/include/ guththila/samples/ guththila/src/ include/ mod...

Modified: webservices/axis2/trunk/c/woden/src/wsdl20/extensions/soap/woden_soap_binding_msg_ref_exts.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/wsdl20/extensions/soap/woden_soap_binding_msg_ref_exts.c?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/woden/src/wsdl20/extensions/soap/woden_soap_binding_msg_ref_exts.c (original)
+++ webservices/axis2/trunk/c/woden/src/wsdl20/extensions/soap/woden_soap_binding_msg_ref_exts.c Fri Mar 30 12:24:00 2007
@@ -37,7 +37,7 @@
     axutil_hash_t *super;
     woden_obj_types_t obj_type;
 
-    axis2_qname_t *qname;
+    axutil_qname_t *qname;
 };
 
 #define INTF_TO_IMPL(binding_msg_ref_exts) ((woden_soap_binding_msg_ref_exts_impl_t *) binding_msg_ref_exts)
@@ -238,7 +238,7 @@
 
     if (binding_msg_ref_exts_impl->qname)
     {
-        axis2_qname_free(binding_msg_ref_exts_impl->qname, env);
+        axutil_qname_free(binding_msg_ref_exts_impl->qname, env);
         binding_msg_ref_exts_impl->qname = NULL;
     }
     woden_soap_binding_msg_ref_exts_free_ops(binding_msg_ref_exts, env);
@@ -347,7 +347,7 @@
                 binding_msg_ref_exts_impl->component_exts, env);
     parent_element = woden_wsdl_element_to_element_extensible(parent_element,
             env);
-    binding_msg_ref_exts_impl->qname = axis2_qname_create_from_string(env,
+    binding_msg_ref_exts_impl->qname = axutil_qname_create_from_string(env,
             WODEN_Q_ELEM_SOAP_MODULE);
     soap_mods = WODEN_ELEMENT_EXTENSIBLE_GET_EXT_ELEMENTS_OF_TYPE(
                 parent_element, env, binding_msg_ref_exts_impl->qname);
@@ -371,7 +371,7 @@
                 binding_msg_ref_exts_impl->component_exts, env);
     parent_element = woden_wsdl_element_to_element_extensible(parent_element,
             env);
-    binding_msg_ref_exts_impl->qname = axis2_qname_create_from_string(env,
+    binding_msg_ref_exts_impl->qname = axutil_qname_create_from_string(env,
             WODEN_Q_ELEM_SOAP_HEADER);
     soap_headers = WODEN_ELEMENT_EXTENSIBLE_GET_EXT_ELEMENTS_OF_TYPE(
                 parent_element, env, binding_msg_ref_exts_impl->qname);

Modified: webservices/axis2/trunk/c/woden/src/wsdl20/extensions/soap/woden_soap_binding_op_exts.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/wsdl20/extensions/soap/woden_soap_binding_op_exts.c?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/woden/src/wsdl20/extensions/soap/woden_soap_binding_op_exts.c (original)
+++ webservices/axis2/trunk/c/woden/src/wsdl20/extensions/soap/woden_soap_binding_op_exts.c Fri Mar 30 12:24:00 2007
@@ -38,7 +38,7 @@
     axutil_hash_t *super;
     woden_obj_types_t obj_type;
 
-    axis2_qname_t *qname;
+    axutil_qname_t *qname;
 };
 
 #define INTF_TO_IMPL(binding_op_exts) ((woden_soap_binding_op_exts_impl_t *) binding_op_exts)
@@ -249,7 +249,7 @@
 
     if (binding_op_exts_impl->qname)
     {
-        axis2_qname_free(binding_op_exts_impl->qname, env);
+        axutil_qname_free(binding_op_exts_impl->qname, env);
         binding_op_exts_impl->qname = NULL;
     }
     woden_soap_binding_op_exts_free_ops(binding_op_exts, env);
@@ -352,7 +352,7 @@
                 binding_op_exts_impl->component_exts, env);
     parent_element = woden_wsdl_element_to_attr_extensible(parent_element,
             env);
-    binding_op_exts_impl->qname = axis2_qname_create_from_string(env,
+    binding_op_exts_impl->qname = axutil_qname_create_from_string(env,
             WODEN_Q_ATTR_SOAP_MEP);
     mep = WODEN_ATTR_EXTENSIBLE_GET_EXT_ATTR(
                 parent_element, env, binding_op_exts_impl->qname);
@@ -376,7 +376,7 @@
                 binding_op_exts_impl->component_exts, env);
     parent_element = woden_wsdl_element_to_attr_extensible(parent_element,
             env);
-    binding_op_exts_impl->qname = axis2_qname_create_from_string(env,
+    binding_op_exts_impl->qname = axutil_qname_create_from_string(env,
             WODEN_Q_ATTR_SOAP_ACTION);
     action = WODEN_ATTR_EXTENSIBLE_GET_EXT_ATTR(
                 parent_element, env, binding_op_exts_impl->qname);
@@ -400,7 +400,7 @@
                 binding_op_exts_impl->component_exts, env);
     parent_element = woden_wsdl_element_to_element_extensible(parent_element,
             env);
-    binding_op_exts_impl->qname = axis2_qname_create_from_string(env,
+    binding_op_exts_impl->qname = axutil_qname_create_from_string(env,
             WODEN_Q_ELEM_SOAP_MODULE);
     soap_mods = WODEN_ELEMENT_EXTENSIBLE_GET_EXT_ELEMENTS_OF_TYPE(
                 parent_element, env, binding_op_exts_impl->qname);

Modified: webservices/axis2/trunk/c/woden/src/wsdl20/extensions/soap/woden_soap_header_block.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/wsdl20/extensions/soap/woden_soap_header_block.c?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/woden/src/wsdl20/extensions/soap/woden_soap_header_block.c (original)
+++ webservices/axis2/trunk/c/woden/src/wsdl20/extensions/soap/woden_soap_header_block.c Fri Mar 30 12:24:00 2007
@@ -38,11 +38,11 @@
 
     void *f_parent;
     axutil_array_list_t *f_documentation_elements;
-    axis2_qname_t *f_ext_element_type;
+    axutil_qname_t *f_ext_element_type;
     axis2_bool_t f_required;
     void *f_attr_ext;
     void *f_elem_ext;
-    axis2_qname_t *f_element_decl_qn;
+    axutil_qname_t *f_element_decl_qn;
     void *f_element_decl;
     axis2_bool_t f_must_understand;
     void *f_types;
@@ -102,9 +102,9 @@
 woden_soap_header_block_set_element_qname(
     void *header_block,
     const axutil_env_t *env,
-    axis2_qname_t *qname);
+    axutil_qname_t *qname);
 
-axis2_qname_t *AXIS2_CALL
+axutil_qname_t *AXIS2_CALL
 woden_soap_header_block_get_element_qname(
     void *header_block,
     const axutil_env_t *env);
@@ -146,9 +146,9 @@
 woden_soap_header_block_set_extension_type(
     void *header_block,
     const axutil_env_t *env,
-    axis2_qname_t *qname);
+    axutil_qname_t *qname);
 
-axis2_qname_t *AXIS2_CALL
+axutil_qname_t *AXIS2_CALL
 woden_soap_header_block_get_extension_type(
     void *header_block,
     const axutil_env_t *env);
@@ -167,14 +167,14 @@
 woden_soap_header_block_set_ext_attr(
     void *header_block,
     const axutil_env_t *env,
-    axis2_qname_t *attr_type,
+    axutil_qname_t *attr_type,
     void *attr);
 
 void *AXIS2_CALL
 woden_soap_header_block_get_ext_attr(
     void *header_block,
     const axutil_env_t *env,
-    axis2_qname_t *attr_type);
+    axutil_qname_t *attr_type);
 
 axutil_array_list_t *AXIS2_CALL
 woden_soap_header_block_get_ext_attrs_for_namespace(
@@ -214,7 +214,7 @@
 woden_soap_header_block_get_ext_elements_of_type(
     void *header_block,
     const axutil_env_t *env,
-    axis2_qname_t *ext_type);
+    axutil_qname_t *ext_type);
 
 axis2_bool_t AXIS2_CALL
 woden_soap_header_block_has_ext_elements_for_namespace(
@@ -628,7 +628,7 @@
 
     if (header_block_impl->f_ext_element_type)
     {
-        axis2_qname_free(header_block_impl->f_ext_element_type, env);
+        axutil_qname_free(header_block_impl->f_ext_element_type, env);
         header_block_impl->f_ext_element_type = NULL;
     }
 
@@ -646,7 +646,7 @@
 
     if (header_block_impl->f_element_decl_qn)
     {
-        axis2_qname_free(header_block_impl->f_element_decl_qn, env);
+        axutil_qname_free(header_block_impl->f_element_decl_qn, env);
         header_block_impl->f_element_decl_qn = NULL;
     }
 
@@ -864,7 +864,7 @@
 woden_soap_header_block_set_element_qname(
     void *header_block,
     const axutil_env_t *env,
-    axis2_qname_t *qname)
+    axutil_qname_t *qname)
 {
     woden_soap_header_block_impl_t *header_block_impl = NULL;
     axutil_hash_t *super = NULL;
@@ -876,17 +876,17 @@
 
     if (header_block_impl->f_element_decl_qn)
     {
-        axis2_qname_free(header_block_impl->f_element_decl_qn, env);
+        axutil_qname_free(header_block_impl->f_element_decl_qn, env);
         header_block_impl->f_element_decl_qn = NULL;
     }
 
-    header_block_impl->f_element_decl_qn = axis2_qname_clone(qname, env);
+    header_block_impl->f_element_decl_qn = axutil_qname_clone(qname, env);
 
     return AXIS2_SUCCESS;
 
 }
 
-axis2_qname_t *AXIS2_CALL
+axutil_qname_t *AXIS2_CALL
 woden_soap_header_block_get_element_qname(
     void *header_block,
     const axutil_env_t *env)
@@ -1034,7 +1034,7 @@
 woden_soap_header_block_set_extension_type(
     void *header_block,
     const axutil_env_t *env,
-    axis2_qname_t *qname)
+    axutil_qname_t *qname)
 {
     woden_soap_header_block_impl_t *header_block_impl = NULL;
     axutil_hash_t *super = NULL;
@@ -1046,16 +1046,16 @@
 
     if (header_block_impl->f_ext_element_type)
     {
-        axis2_qname_free(header_block_impl->f_ext_element_type, env);
+        axutil_qname_free(header_block_impl->f_ext_element_type, env);
         header_block_impl->f_ext_element_type = NULL;
     }
 
-    header_block_impl->f_ext_element_type = axis2_qname_clone(qname, env);
+    header_block_impl->f_ext_element_type = axutil_qname_clone(qname, env);
 
     return AXIS2_SUCCESS;
 }
 
-axis2_qname_t *AXIS2_CALL
+axutil_qname_t *AXIS2_CALL
 woden_soap_header_block_get_extension_type(
     void *header_block,
     const axutil_env_t *env)
@@ -1098,7 +1098,7 @@
 woden_soap_header_block_set_ext_attr(
     void *header_block,
     const axutil_env_t *env,
-    axis2_qname_t *attr_type,
+    axutil_qname_t *attr_type,
     void *attr)
 {
     woden_soap_header_block_impl_t *header_block_impl = NULL;
@@ -1119,7 +1119,7 @@
 woden_soap_header_block_get_ext_attr(
     void *header_block,
     const axutil_env_t *env,
-    axis2_qname_t *attr_type)
+    axutil_qname_t *attr_type)
 {
     woden_soap_header_block_impl_t *header_block_impl = NULL;
     axutil_hash_t *super = NULL;
@@ -1250,7 +1250,7 @@
 woden_soap_header_block_get_ext_elements_of_type(
     void *header_block,
     const axutil_env_t *env,
-    axis2_qname_t *ext_type)
+    axutil_qname_t *ext_type)
 {
     woden_soap_header_block_impl_t *header_block_impl = NULL;
     axutil_hash_t *super = NULL;

Modified: webservices/axis2/trunk/c/woden/src/wsdl20/extensions/soap/woden_soap_header_block_deserializer.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/wsdl20/extensions/soap/woden_soap_header_block_deserializer.c?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/woden/src/wsdl20/extensions/soap/woden_soap_header_block_deserializer.c (original)
+++ webservices/axis2/trunk/c/woden/src/wsdl20/extensions/soap/woden_soap_header_block_deserializer.c Fri Mar 30 12:24:00 2007
@@ -69,7 +69,7 @@
     const axutil_env_t *env,
     axis2_char_t *parent_type,
     void *parent,
-    axis2_qname_t *ext_type,
+    axutil_qname_t *ext_type,
     axiom_node_t *ext_el_node,
     void *desc,
     woden_ext_registry_t *ext_reg);
@@ -308,7 +308,7 @@
     const axutil_env_t *env,
     axis2_char_t *parent_type,
     void *parent,
-    axis2_qname_t *ext_type,
+    axutil_qname_t *ext_type,
     axiom_node_t *ext_el_node,
     void *desc,
     woden_ext_registry_t *ext_reg)
@@ -343,7 +343,7 @@
             WODEN_ATTR_ELEMENT);
     if (element_decl_qn)
     {
-        axis2_qname_t *qname = NULL;
+        axutil_qname_t *qname = NULL;
         axutil_hash_t *namespcs = NULL;
 
         desc = woden_desc_to_desc_element(desc, env);
@@ -382,12 +382,12 @@
 
     while (temp_el && NULL != temp_el_node)
     {
-        axis2_qname_t *q_elem_documentation = NULL;
+        axutil_qname_t *q_elem_documentation = NULL;
 
-        q_elem_documentation = axis2_qname_create_from_string(env,
+        q_elem_documentation = axutil_qname_create_from_string(env,
                 WODEN_Q_ELEM_DOCUMENTATION);
 
-        if (AXIS2_TRUE == axis2_qname_util_matches(env,
+        if (AXIS2_TRUE == axutil_qname_util_matches(env,
                 q_elem_documentation, temp_el_node))
         {
             void *documentation = NULL;

Modified: webservices/axis2/trunk/c/woden/src/wsdl20/extensions/soap/woden_soap_module.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/wsdl20/extensions/soap/woden_soap_module.c?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/woden/src/wsdl20/extensions/soap/woden_soap_module.c (original)
+++ webservices/axis2/trunk/c/woden/src/wsdl20/extensions/soap/woden_soap_module.c Fri Mar 30 12:24:00 2007
@@ -37,7 +37,7 @@
 
     void *f_parent;
     axutil_array_list_t *f_documentation_elements;
-    axis2_qname_t *f_ext_element_type;
+    axutil_qname_t *f_ext_element_type;
     axis2_bool_t f_required;
     void *f_attr_ext;
     void *f_elem_ext;
@@ -121,9 +121,9 @@
 woden_soap_module_set_extension_type(
     void *module,
     axutil_env_t *env,
-    axis2_qname_t *qname);
+    axutil_qname_t *qname);
 
-axis2_qname_t *AXIS2_CALL
+axutil_qname_t *AXIS2_CALL
 woden_soap_module_get_extension_type(
     void *module,
     axutil_env_t *env);
@@ -142,14 +142,14 @@
 woden_soap_module_set_ext_attr(
     void *module,
     axutil_env_t *env,
-    axis2_qname_t *attr_type,
+    axutil_qname_t *attr_type,
     void *attr);
 
 void *AXIS2_CALL
 woden_soap_module_get_ext_attr(
     void *module,
     axutil_env_t *env,
-    axis2_qname_t *attr_type);
+    axutil_qname_t *attr_type);
 
 axutil_array_list_t *AXIS2_CALL
 woden_soap_module_get_ext_attrs_for_namespace(
@@ -189,7 +189,7 @@
 woden_soap_module_get_ext_elements_of_type(
     void *module,
     axutil_env_t *env,
-    axis2_qname_t *ext_type);
+    axutil_qname_t *ext_type);
 
 axis2_bool_t AXIS2_CALL
 woden_soap_module_has_ext_elements_for_namespace(
@@ -551,7 +551,7 @@
 
     if (module_impl->f_ext_element_type)
     {
-        axis2_qname_free(module_impl->f_ext_element_type, env);
+        axutil_qname_free(module_impl->f_ext_element_type, env);
         module_impl->f_ext_element_type = NULL;
     }
 
@@ -851,7 +851,7 @@
 woden_soap_module_set_extension_type(
     void *module,
     axutil_env_t *env,
-    axis2_qname_t *qname)
+    axutil_qname_t *qname)
 {
     woden_soap_module_impl_t *module_impl = NULL;
     axutil_hash_t *super = NULL;
@@ -863,16 +863,16 @@
 
     if (module_impl->f_ext_element_type)
     {
-        axis2_qname_free(module_impl->f_ext_element_type, env);
+        axutil_qname_free(module_impl->f_ext_element_type, env);
         module_impl->f_ext_element_type = NULL;
     }
 
-    module_impl->f_ext_element_type = axis2_qname_clone(qname, env);
+    module_impl->f_ext_element_type = axutil_qname_clone(qname, env);
 
     return AXIS2_SUCCESS;
 }
 
-axis2_qname_t *AXIS2_CALL
+axutil_qname_t *AXIS2_CALL
 woden_soap_module_get_extension_type(
     void *module,
     axutil_env_t *env)
@@ -915,7 +915,7 @@
 woden_soap_module_set_ext_attr(
     void *module,
     axutil_env_t *env,
-    axis2_qname_t *attr_type,
+    axutil_qname_t *attr_type,
     void *attr)
 {
     woden_soap_module_impl_t *module_impl = NULL;
@@ -936,7 +936,7 @@
 woden_soap_module_get_ext_attr(
     void *module,
     axutil_env_t *env,
-    axis2_qname_t *attr_type)
+    axutil_qname_t *attr_type)
 {
     woden_soap_module_impl_t *module_impl = NULL;
     axutil_hash_t *super = NULL;
@@ -1067,7 +1067,7 @@
 woden_soap_module_get_ext_elements_of_type(
     void *module,
     axutil_env_t *env,
-    axis2_qname_t *ext_type)
+    axutil_qname_t *ext_type)
 {
     woden_soap_module_impl_t *module_impl = NULL;
     axutil_hash_t *super = NULL;

Modified: webservices/axis2/trunk/c/woden/src/wsdl20/extensions/soap/woden_soap_module_deserializer.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/wsdl20/extensions/soap/woden_soap_module_deserializer.c?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/woden/src/wsdl20/extensions/soap/woden_soap_module_deserializer.c (original)
+++ webservices/axis2/trunk/c/woden/src/wsdl20/extensions/soap/woden_soap_module_deserializer.c Fri Mar 30 12:24:00 2007
@@ -67,7 +67,7 @@
     const axutil_env_t *env,
     axis2_char_t *parent_type,
     void *parent,
-    axis2_qname_t *element_type,
+    axutil_qname_t *element_type,
     axiom_node_t *el_node,
     void *desc,
     woden_ext_registry_t *ext_reg);
@@ -306,7 +306,7 @@
     const axutil_env_t *env,
     axis2_char_t *parent_type,
     void *parent,
-    axis2_qname_t *element_type,
+    axutil_qname_t *element_type,
     axiom_node_t *el_node,
     void *desc,
     woden_ext_registry_t *ext_reg)
@@ -362,12 +362,12 @@
             &temp_el_node);
     while (temp_el && NULL != temp_el_node)
     {
-        axis2_qname_t *q_elem_documentation = NULL;
+        axutil_qname_t *q_elem_documentation = NULL;
 
-        q_elem_documentation = axis2_qname_create_from_string(env,
+        q_elem_documentation = axutil_qname_create_from_string(env,
                 WODEN_Q_ELEM_DOCUMENTATION);
 
-        if (AXIS2_TRUE == axis2_qname_util_matches(env,
+        if (AXIS2_TRUE == axutil_qname_util_matches(env,
                 q_elem_documentation, temp_el_node))
         {
             void *documentation = NULL;

Modified: webservices/axis2/trunk/c/woden/src/wsdl20/extensions/woden_ext_registry.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/wsdl20/extensions/woden_ext_registry.c?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/woden/src/wsdl20/extensions/woden_ext_registry.c (original)
+++ webservices/axis2/trunk/c/woden/src/wsdl20/extensions/woden_ext_registry.c Fri Mar 30 12:24:00 2007
@@ -100,7 +100,7 @@
     void *registry,
     const axutil_env_t *env,
     axis2_char_t *parent_type,
-    axis2_qname_t *element_qtype,
+    axutil_qname_t *element_qtype,
     void *ed);
 
 void *AXIS2_CALL
@@ -108,14 +108,14 @@
     void *registry,
     const axutil_env_t *env,
     axis2_char_t *parent_type,
-    axis2_qname_t *element_type);
+    axutil_qname_t *element_type);
 
 void *AXIS2_CALL
 woden_ext_registry_query_ext_element_type(
     void *registry,
     const axutil_env_t *env,
     axis2_char_t *parent_class,
-    axis2_qname_t *elem_qn);
+    axutil_qname_t *elem_qn);
 
 axutil_array_list_t *AXIS2_CALL
 woden_ext_registry_get_allowable_exts(
@@ -128,7 +128,7 @@
     void *registry,
     const axutil_env_t *env,
     axis2_char_t *parent_type,
-    axis2_qname_t *element_qtype,
+    axutil_qname_t *element_qtype,
     void *element);
 
 axis2_status_t AXIS2_CALL
@@ -136,7 +136,7 @@
     void *registry,
     const axutil_env_t *env,
     axis2_char_t *owner_class,
-    axis2_qname_t *attr_qname,
+    axutil_qname_t *attr_qname,
     void *attr);
 
 void *AXIS2_CALL
@@ -144,7 +144,7 @@
     void *registry,
     const axutil_env_t *env,
     axis2_char_t *parent_class,
-    axis2_qname_t *attr_qn);
+    axutil_qname_t *attr_qn);
 
 axis2_status_t AXIS2_CALL
 woden_ext_registry_register_component_ext(
@@ -321,7 +321,7 @@
     void *registry,
     const axutil_env_t *env,
     axis2_char_t *parent_type,
-    axis2_qname_t *element_qtype,
+    axutil_qname_t *element_qtype,
     void *ed)
 {
     woden_ext_registry_impl_t *registry_impl = NULL;
@@ -339,7 +339,7 @@
         axutil_hash_set(registry_impl->deserializer_reg, parent_type,
                 AXIS2_HASH_KEY_STRING, inner_deserializer_reg);
     }
-    element_type = axis2_qname_to_string(element_qtype, env);
+    element_type = axutil_qname_to_string(element_qtype, env);
     axutil_hash_set(inner_deserializer_reg, element_type, AXIS2_HASH_KEY_STRING,
             ed);
     return AXIS2_SUCCESS;
@@ -366,7 +366,7 @@
     void *registry,
     const axutil_env_t *env,
     axis2_char_t *parent_type,
-    axis2_qname_t *element_type)
+    axutil_qname_t *element_type)
 {
     woden_ext_registry_impl_t *registry_impl = NULL;
     axutil_hash_t *inner_deserializer_reg = NULL;
@@ -378,7 +378,7 @@
 
     inner_deserializer_reg = axutil_hash_get(registry_impl->deserializer_reg,
             parent_type, AXIS2_HASH_KEY_STRING);
-    elem_name = axis2_qname_to_string(element_type, env);
+    elem_name = axutil_qname_to_string(element_type, env);
     if (inner_deserializer_reg)
     {
         ed = axutil_hash_get(inner_deserializer_reg, elem_name,
@@ -405,7 +405,7 @@
     void *registry,
     const axutil_env_t *env,
     axis2_char_t *parent_class,
-    axis2_qname_t *elem_qn)
+    axutil_qname_t *elem_qn)
 {
     woden_ext_registry_impl_t *registry_impl = NULL;
     axutil_hash_t *inner_ext_attr_reg = NULL;
@@ -417,7 +417,7 @@
 
     inner_ext_attr_reg = axutil_hash_get(registry_impl->ext_attr_reg,
             parent_class, AXIS2_HASH_KEY_STRING);
-    elem_name = axis2_qname_to_string(elem_qn, env);
+    elem_name = axutil_qname_to_string(elem_qn, env);
     if (inner_ext_attr_reg)
     {
         element = axutil_hash_get(inner_ext_attr_reg, elem_name,
@@ -486,7 +486,7 @@
     void *registry,
     const axutil_env_t *env,
     axis2_char_t *parent_type,
-    axis2_qname_t *element_qtype,
+    axutil_qname_t *element_qtype,
     void *element)
 {
     woden_ext_registry_impl_t *registry_impl = NULL;
@@ -504,7 +504,7 @@
         axutil_hash_set(registry_impl->ext_element_reg, parent_type,
                 AXIS2_HASH_KEY_STRING, inner_ext_type_reg);
     }
-    element_type = axis2_qname_to_string(element_qtype, env);
+    element_type = axutil_qname_to_string(element_qtype, env);
     axutil_hash_set(inner_ext_type_reg, element_type, AXIS2_HASH_KEY_STRING,
             element);
     return AXIS2_SUCCESS;
@@ -529,7 +529,7 @@
     void *registry,
     const axutil_env_t *env,
     axis2_char_t *owner_class,
-    axis2_qname_t *attr_qname,
+    axutil_qname_t *attr_qname,
     void *attr)
 {
     woden_ext_registry_impl_t *registry_impl = NULL;
@@ -547,7 +547,7 @@
         axutil_hash_set(registry_impl->ext_attr_reg, owner_class,
                 AXIS2_HASH_KEY_STRING, inner_ext_attr_reg);
     }
-    attr_name = axis2_qname_to_string(attr_qname, env);
+    attr_name = axutil_qname_to_string(attr_qname, env);
     axutil_hash_set(inner_ext_attr_reg, attr_name, AXIS2_HASH_KEY_STRING, attr);
     return AXIS2_SUCCESS;
 }
@@ -569,7 +569,7 @@
     void *registry,
     const axutil_env_t *env,
     axis2_char_t *parent_class,
-    axis2_qname_t *attr_qn)
+    axutil_qname_t *attr_qn)
 {
     woden_ext_registry_impl_t *registry_impl = NULL;
     axutil_hash_t *inner_ext_attr_reg = NULL;
@@ -581,7 +581,7 @@
 
     inner_ext_attr_reg = axutil_hash_get(registry_impl->ext_attr_reg,
             parent_class, AXIS2_HASH_KEY_STRING);
-    attr_name = axis2_qname_to_string(attr_qn, env);
+    attr_name = axutil_qname_to_string(attr_qn, env);
     if (inner_ext_attr_reg)
     {
         attr = axutil_hash_get(inner_ext_attr_reg, attr_name,
@@ -703,15 +703,15 @@
     const axutil_env_t *env)
 {
     woden_ext_registry_impl_t *registry_impl = NULL;
-    axis2_qname_t *q_attr_soap_version = NULL;
-    axis2_qname_t *q_attr_soap_protocol = NULL;
-    axis2_qname_t *q_attr_soap_mepdefault = NULL;
-    axis2_qname_t *q_attr_soap_code = NULL;
-    axis2_qname_t *q_attr_soap_subcodes = NULL;
-    axis2_qname_t *q_attr_soap_mep = NULL;
-    axis2_qname_t *q_attr_soap_action = NULL;
-    axis2_qname_t *q_elem_soap_module = NULL;
-    axis2_qname_t *q_elem_soap_header = NULL;
+    axutil_qname_t *q_attr_soap_version = NULL;
+    axutil_qname_t *q_attr_soap_protocol = NULL;
+    axutil_qname_t *q_attr_soap_mepdefault = NULL;
+    axutil_qname_t *q_attr_soap_code = NULL;
+    axutil_qname_t *q_attr_soap_subcodes = NULL;
+    axutil_qname_t *q_attr_soap_mep = NULL;
+    axutil_qname_t *q_attr_soap_action = NULL;
+    axutil_qname_t *q_elem_soap_module = NULL;
+    axutil_qname_t *q_elem_soap_header = NULL;
     axis2_uri_t *uri_ns_soap = NULL;
 
     AXIS2_ENV_CHECK(env, AXIS2_FAILURE);
@@ -729,37 +729,37 @@
         woden_qname_list_or_token_any_attr_create(env, NULL, NULL, NULL,
                 NULL);
 
-    q_attr_soap_version = axis2_qname_create_from_string(env, WODEN_Q_ATTR_SOAP_VERSION);
+    q_attr_soap_version = axutil_qname_create_from_string(env, WODEN_Q_ATTR_SOAP_VERSION);
     woden_ext_registry_register_ext_attr_type(registry, env,
             "binding_element", q_attr_soap_version,
             registry_impl->string_attr);
 
-    q_attr_soap_protocol = axis2_qname_create_from_string(env, WODEN_Q_ATTR_SOAP_PROTOCOL);
+    q_attr_soap_protocol = axutil_qname_create_from_string(env, WODEN_Q_ATTR_SOAP_PROTOCOL);
     woden_ext_registry_register_ext_attr_type(registry, env,
             "binding_element", q_attr_soap_protocol,
             registry_impl->uri_attr);
 
-    q_attr_soap_mepdefault = axis2_qname_create_from_string(env, WODEN_Q_ATTR_SOAP_MEPDEFAULT);
+    q_attr_soap_mepdefault = axutil_qname_create_from_string(env, WODEN_Q_ATTR_SOAP_MEPDEFAULT);
     woden_ext_registry_register_ext_attr_type(registry, env,
             "binding_element", q_attr_soap_mepdefault,
             registry_impl->uri_attr);
 
-    q_attr_soap_code = axis2_qname_create_from_string(env, WODEN_Q_ATTR_SOAP_CODE);
+    q_attr_soap_code = axutil_qname_create_from_string(env, WODEN_Q_ATTR_SOAP_CODE);
     woden_ext_registry_register_ext_attr_type(registry, env,
             "binding_fault_element", q_attr_soap_code,
             registry_impl->qname_or_token_any_attr);
 
-    q_attr_soap_subcodes = axis2_qname_create_from_string(env, WODEN_Q_ATTR_SOAP_SUBCODES);
+    q_attr_soap_subcodes = axutil_qname_create_from_string(env, WODEN_Q_ATTR_SOAP_SUBCODES);
     woden_ext_registry_register_ext_attr_type(registry, env,
             "binding_fault_element", q_attr_soap_subcodes,
             registry_impl->qname_list_or_token_any_attr);
 
-    q_attr_soap_mep = axis2_qname_create_from_string(env, WODEN_Q_ATTR_SOAP_MEP);
+    q_attr_soap_mep = axutil_qname_create_from_string(env, WODEN_Q_ATTR_SOAP_MEP);
     woden_ext_registry_register_ext_attr_type(registry, env,
             "binding_op_element", q_attr_soap_mep,
             registry_impl->uri_attr);
 
-    q_attr_soap_action = axis2_qname_create_from_string(env, WODEN_Q_ATTR_SOAP_ACTION);
+    q_attr_soap_action = axutil_qname_create_from_string(env, WODEN_Q_ATTR_SOAP_ACTION);
     woden_ext_registry_register_ext_attr_type(registry, env,
             "binding_op_element", q_attr_soap_action,
             registry_impl->uri_attr);
@@ -770,7 +770,7 @@
         woden_soap_module_deserializer_create(env);
     registry_impl->soap_module = woden_soap_module_create(env);
 
-    q_elem_soap_module = axis2_qname_create_from_string(env, WODEN_Q_ELEM_SOAP_MODULE);
+    q_elem_soap_module = axutil_qname_create_from_string(env, WODEN_Q_ELEM_SOAP_MODULE);
 
     woden_ext_registry_register_deserializer(registry, env, "binding_element",
             q_elem_soap_module,
@@ -817,7 +817,7 @@
         woden_soap_header_block_deserializer_create(env);
     registry_impl->soap_header_block = woden_soap_header_block_create(env);
 
-    q_elem_soap_header = axis2_qname_create_from_string(env, WODEN_Q_ELEM_SOAP_HEADER);
+    q_elem_soap_header = axutil_qname_create_from_string(env, WODEN_Q_ELEM_SOAP_HEADER);
 
     woden_ext_registry_register_deserializer(registry, env, "binding_fault_element",
             q_elem_soap_header,

Modified: webservices/axis2/trunk/c/woden/src/wsdl20/woden_binding_fault.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/wsdl20/woden_binding_fault.c?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/woden/src/wsdl20/woden_binding_fault.c (original)
+++ webservices/axis2/trunk/c/woden/src/wsdl20/woden_binding_fault.c Fri Mar 30 12:24:00 2007
@@ -39,7 +39,7 @@
     woden_obj_types_t obj_type;
     axutil_hash_t *super;
     axutil_hash_t *methods;
-    axis2_qname_t *f_ref;
+    axutil_qname_t *f_ref;
     void *f_interface_fault;
 };
 
@@ -84,9 +84,9 @@
 woden_binding_fault_set_ref(
     void *binding_fault,
     const axutil_env_t *env,
-    axis2_qname_t *qname);
+    axutil_qname_t *qname);
 
-axis2_qname_t *AXIS2_CALL
+axutil_qname_t *AXIS2_CALL
 woden_binding_fault_get_ref(
     void *binding_fault,
     const axutil_env_t *env);
@@ -684,7 +684,7 @@
 
     if (binding_fault_impl->f_ref)
     {
-        axis2_qname_free(binding_fault_impl->f_ref, env);
+        axutil_qname_free(binding_fault_impl->f_ref, env);
         binding_fault_impl->f_ref = NULL;
     }
 
@@ -852,7 +852,7 @@
 woden_binding_fault_set_ref(
     void *binding_fault,
     const axutil_env_t *env,
-    axis2_qname_t *qname)
+    axutil_qname_t *qname)
 {
     woden_binding_fault_impl_t *binding_fault_impl = NULL;
     axutil_hash_t *super = NULL;
@@ -865,13 +865,13 @@
 
     if (binding_fault_impl->f_ref)
     {
-        axis2_qname_free(binding_fault_impl->f_ref, env);
+        axutil_qname_free(binding_fault_impl->f_ref, env);
     }
-    binding_fault_impl->f_ref = axis2_qname_clone(qname, env);
+    binding_fault_impl->f_ref = axutil_qname_clone(qname, env);
     return AXIS2_SUCCESS;
 }
 
-axis2_qname_t *AXIS2_CALL
+axutil_qname_t *AXIS2_CALL
 woden_binding_fault_get_ref(
     void *binding_fault,
     const axutil_env_t *env)

Modified: webservices/axis2/trunk/c/woden/src/wsdl20/woden_binding_op.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/wsdl20/woden_binding_op.c?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/woden/src/wsdl20/woden_binding_op.c (original)
+++ webservices/axis2/trunk/c/woden/src/wsdl20/woden_binding_op.c Fri Mar 30 12:24:00 2007
@@ -38,7 +38,7 @@
     woden_obj_types_t obj_type;
     axutil_hash_t *super;
     axutil_hash_t *methods;
-    axis2_qname_t *f_ref;
+    axutil_qname_t *f_ref;
     axutil_array_list_t *f_msg_refs;
     axutil_array_list_t *f_fault_refs;
     void *f_interface_op;
@@ -96,9 +96,9 @@
 woden_binding_op_set_ref(
     void *binding_op,
     const axutil_env_t *env,
-    axis2_qname_t *qname);
+    axutil_qname_t *qname);
 
-axis2_qname_t *AXIS2_CALL
+axutil_qname_t *AXIS2_CALL
 woden_binding_op_get_ref(
     void *binding_op,
     const axutil_env_t *env);
@@ -803,7 +803,7 @@
 
     if (binding_op_impl->f_ref)
     {
-        axis2_qname_free(binding_op_impl->f_ref, env);
+        axutil_qname_free(binding_op_impl->f_ref, env);
         binding_op_impl->f_ref = NULL;
     }
 
@@ -1031,7 +1031,7 @@
 woden_binding_op_set_ref(
     void *binding_op,
     const axutil_env_t *env,
-    axis2_qname_t *qname)
+    axutil_qname_t *qname)
 {
     woden_binding_op_impl_t *binding_op_impl = NULL;
     axutil_hash_t *super = NULL;
@@ -1044,15 +1044,15 @@
 
     if (binding_op_impl->f_ref)
     {
-        axis2_qname_free(binding_op_impl->f_ref, env);
+        axutil_qname_free(binding_op_impl->f_ref, env);
         binding_op_impl->f_ref = NULL;
     }
-    binding_op_impl->f_ref = axis2_qname_clone(qname, env);
+    binding_op_impl->f_ref = axutil_qname_clone(qname, env);
 
     return AXIS2_SUCCESS;
 }
 
-axis2_qname_t *AXIS2_CALL
+axutil_qname_t *AXIS2_CALL
 woden_binding_op_get_ref(
     void *binding_op,
     const axutil_env_t *env)

Modified: webservices/axis2/trunk/c/woden/src/wsdl20/woden_component_model_builder.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/wsdl20/woden_component_model_builder.c?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/woden/src/wsdl20/woden_component_model_builder.c (original)
+++ webservices/axis2/trunk/c/woden/src/wsdl20/woden_component_model_builder.c Fri Mar 30 12:24:00 2007
@@ -485,12 +485,12 @@
             size = axutil_array_list_size(qnames, env);
         for (i = 0; i < size; i++)
         {
-            axis2_qname_t *qname = NULL;
+            axutil_qname_t *qname = NULL;
             axis2_char_t *namespc = NULL;
 
-            qname = (axis2_qname_t *) axutil_array_list_get(qnames, env, i);
+            qname = (axutil_qname_t *) axutil_array_list_get(qnames, env, i);
             if (qname)
-                namespc = axis2_qname_get_uri(qname, env);
+                namespc = axutil_qname_get_uri(qname, env);
             if (0 == axis2_strcmp(namespc, schema_tns))
             {
                 void *ed = NULL;
@@ -542,12 +542,12 @@
             size = axutil_array_list_size(qnames, env);
         for (i = 0; i < size; i++)
         {
-            axis2_qname_t *qname = NULL;
+            axutil_qname_t *qname = NULL;
             axis2_char_t *namespc = NULL;
 
-            qname = (axis2_qname_t *) axutil_array_list_get(qnames, env, i);
+            qname = (axutil_qname_t *) axutil_array_list_get(qnames, env, i);
             if (qname)
-                namespc = axis2_qname_get_uri(qname, env);
+                namespc = axutil_qname_get_uri(qname, env);
             if (0 == axis2_strcmp(namespc, schema_tns))
             {
                 void *td = NULL;
@@ -653,7 +653,7 @@
     {
         void *fault = NULL;
         axutil_array_list_t *property_elements = NULL;
-        axis2_qname_t *qname = NULL;
+        axutil_qname_t *qname = NULL;
 
         fault = axutil_array_list_get(faults, env, i);
         fault = woden_interface_fault_to_configurable_element(fault, env);
@@ -732,7 +732,7 @@
     {
         void *fault_ref = NULL;
         axutil_array_list_t *property_elements = NULL;
-        axis2_qname_t *qname = NULL;
+        axutil_qname_t *qname = NULL;
 
         fault_ref = axutil_array_list_get(fault_refs, env, i);
         fault_ref = woden_interface_fault_ref_to_configurable_element(fault_ref, env);
@@ -790,7 +790,7 @@
                     msg, env);
         if (0 == axis2_strcmp(WODEN_NMTOKEN_ELEMENT, msg_content_model))
         {
-            axis2_qname_t *qname = NULL;
+            axutil_qname_t *qname = NULL;
             msg = woden_interface_msg_ref_to_interface_msg_ref_element(msg, env);
             qname = WODEN_INTERFACE_MSG_REF_ELEMENT_GET_ELEMENT_QNAME(msg, env);
             if (qname)
@@ -1490,7 +1490,7 @@
     for (i = 0; i < size; i++)
     {
         void *prop = NULL;
-        axis2_qname_t *qname = NULL;
+        axutil_qname_t *qname = NULL;
 
         prop = axutil_array_list_get(prop_els, env, i);
         prop = woden_property_to_property_element(prop, env);

Modified: webservices/axis2/trunk/c/woden/src/wsdl20/woden_desc.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/wsdl20/woden_desc.c?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/woden/src/wsdl20/woden_desc.c (original)
+++ webservices/axis2/trunk/c/woden/src/wsdl20/woden_desc.c Fri Mar 30 12:24:00 2007
@@ -135,7 +135,7 @@
 woden_desc_get_element_decl(
     void *desc,
     const axutil_env_t *env,
-    axis2_qname_t *qname);
+    axutil_qname_t *qname);
 
 axutil_array_list_t *AXIS2_CALL
 woden_desc_get_type_defs(
@@ -146,7 +146,7 @@
 woden_desc_get_type_def(
     void *desc,
     const axutil_env_t *env,
-    axis2_qname_t *qname);
+    axutil_qname_t *qname);
 
 void *AXIS2_CALL
 woden_desc_to_element(
@@ -1267,7 +1267,7 @@
 woden_desc_get_element_decl(
     void *desc,
     const axutil_env_t *env,
-    axis2_qname_t *qname)
+    axutil_qname_t *qname)
 {
     woden_desc_impl_t *desc_impl = NULL;
     axutil_hash_t *super = NULL;
@@ -1285,10 +1285,10 @@
     size = axutil_array_list_size(desc_impl->f_all_element_decls, env);
     for (i = 0; i < size; i++)
     {
-        axis2_qname_t *qname_l = NULL;
+        axutil_qname_t *qname_l = NULL;
         void *ed = axutil_array_list_get(desc_impl->f_all_element_decls, env, i);
         qname_l = WODEN_ELEMENT_DECL_GET_QNAME(ed, env);
-        if (0 == axis2_qname_equals(qname, env, qname_l))
+        if (0 == axutil_qname_equals(qname, env, qname_l))
         {
             el_decl = ed;
             break;
@@ -1319,7 +1319,7 @@
 woden_desc_get_type_def(
     void *desc,
     const axutil_env_t *env,
-    axis2_qname_t *qname)
+    axutil_qname_t *qname)
 {
     woden_desc_impl_t *desc_impl = NULL;
     axutil_hash_t *super = NULL;
@@ -1337,10 +1337,10 @@
     size = axutil_array_list_size(desc_impl->f_all_element_decls, env);
     for (i = 0; i < size; i++)
     {
-        axis2_qname_t *qname_l = NULL;
+        axutil_qname_t *qname_l = NULL;
         void *ed = axutil_array_list_get(desc_impl->f_all_element_decls, env, i);
         qname_l = WODEN_TYPE_DEF_GET_QNAME(ed, env);
-        if (0 == axis2_qname_equals(qname, env, qname_l))
+        if (0 == axutil_qname_equals(qname, env, qname_l))
         {
             type_def = ed;
             break;

Modified: webservices/axis2/trunk/c/woden/src/wsdl20/woden_endpoint.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/wsdl20/woden_endpoint.c?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/woden/src/wsdl20/woden_endpoint.c (original)
+++ webservices/axis2/trunk/c/woden/src/wsdl20/woden_endpoint.c Fri Mar 30 12:24:00 2007
@@ -38,7 +38,7 @@
     axutil_hash_t *super;
     axutil_hash_t *methods;
     woden_nc_name_t *f_name;
-    axis2_qname_t *f_binding_qname;
+    axutil_qname_t *f_binding_qname;
     void *f_binding;
     axis2_uri_t *f_address;
 };
@@ -97,9 +97,9 @@
 woden_endpoint_set_binding_qname(
     void *endpoint,
     const axutil_env_t *env,
-    axis2_qname_t *binding_qname);
+    axutil_qname_t *binding_qname);
 
-axis2_qname_t *AXIS2_CALL
+axutil_qname_t *AXIS2_CALL
 woden_endpoint_get_binding_qname(
     void *endpoint,
     const axutil_env_t *env);
@@ -720,7 +720,7 @@
 
     if (endpoint_impl->f_binding_qname)
     {
-        axis2_qname_free(endpoint_impl->f_binding_qname, env);
+        axutil_qname_free(endpoint_impl->f_binding_qname, env);
         endpoint_impl->f_binding_qname = NULL;
     }
 
@@ -938,7 +938,7 @@
 woden_endpoint_set_binding_qname(
     void *endpoint,
     const axutil_env_t *env,
-    axis2_qname_t *binding_qname)
+    axutil_qname_t *binding_qname)
 {
     woden_endpoint_impl_t *endpoint_impl = NULL;
     axutil_hash_t *super = NULL;
@@ -950,14 +950,14 @@
 
     if (endpoint_impl->f_binding_qname)
     {
-        axis2_qname_free(endpoint_impl->f_binding_qname, env);
+        axutil_qname_free(endpoint_impl->f_binding_qname, env);
     }
 
-    endpoint_impl->f_binding_qname = axis2_qname_clone(binding_qname, env);
+    endpoint_impl->f_binding_qname = axutil_qname_clone(binding_qname, env);
     return AXIS2_SUCCESS;
 }
 
-axis2_qname_t *AXIS2_CALL
+axutil_qname_t *AXIS2_CALL
 woden_endpoint_get_binding_qname(
     void *endpoint,
     const axutil_env_t *env)

Modified: webservices/axis2/trunk/c/woden/src/wsdl20/woden_interface_fault.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/wsdl20/woden_interface_fault.c?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/woden/src/wsdl20/woden_interface_fault.c (original)
+++ webservices/axis2/trunk/c/woden/src/wsdl20/woden_interface_fault.c Fri Mar 30 12:24:00 2007
@@ -39,9 +39,9 @@
     woden_obj_types_t obj_type;
     axutil_hash_t *super;
     axutil_hash_t *methods;
-    axis2_qname_t *f_qname;
+    axutil_qname_t *f_qname;
     void *f_element_decl;
-    axis2_qname_t *f_element_qname;
+    axutil_qname_t *f_element_qname;
     void *f_types;
 };
 
@@ -70,7 +70,7 @@
 /* ************************************************************
  *  Interface Fault methods (the WSDL Component model)
  * ************************************************************/
-axis2_qname_t *AXIS2_CALL
+axutil_qname_t *AXIS2_CALL
 woden_interface_fault_get_qname(
     void *interface_fault,
     const axutil_env_t *env);
@@ -92,15 +92,15 @@
 woden_interface_fault_set_qname(
     void *interface_fault,
     const axutil_env_t *env,
-    axis2_qname_t *qname);
+    axutil_qname_t *qname);
 
 axis2_status_t AXIS2_CALL
 woden_interface_fault_set_element_qname(
     void *interface_fault,
     const axutil_env_t *env,
-    axis2_qname_t *qname);
+    axutil_qname_t *qname);
 
-axis2_qname_t *AXIS2_CALL
+axutil_qname_t *AXIS2_CALL
 woden_interface_fault_get_element_qname(
     void *interface_fault,
     const axutil_env_t *env);
@@ -588,7 +588,7 @@
 
     if (interface_fault_impl->f_qname)
     {
-        axis2_qname_free(interface_fault_impl->f_qname, env);
+        axutil_qname_free(interface_fault_impl->f_qname, env);
         interface_fault_impl->f_qname = NULL;
     }
 
@@ -601,7 +601,7 @@
 
     if (interface_fault_impl->f_element_qname)
     {
-        axis2_qname_free(interface_fault_impl->f_element_qname, env);
+        axutil_qname_free(interface_fault_impl->f_element_qname, env);
         interface_fault_impl->f_element_qname = NULL;
     }
 
@@ -735,7 +735,7 @@
 /* ************************************************************
  *  Interface Fault interface_fault methods (the WSDL Component model)
  * ************************************************************/
-axis2_qname_t *AXIS2_CALL
+axutil_qname_t *AXIS2_CALL
 woden_interface_fault_get_qname(
     void *interface_fault,
     const axutil_env_t *env)
@@ -790,7 +790,7 @@
 woden_interface_fault_set_qname(
     void *interface_fault,
     const axutil_env_t *env,
-    axis2_qname_t *qname)
+    axutil_qname_t *qname)
 {
     woden_interface_fault_impl_t *interface_fault_impl = NULL;
     axutil_hash_t *super = NULL;
@@ -803,9 +803,9 @@
 
     if (interface_fault_impl->f_qname)
     {
-        axis2_qname_free(interface_fault_impl->f_qname, env);
+        axutil_qname_free(interface_fault_impl->f_qname, env);
     }
-    interface_fault_impl->f_qname = axis2_qname_clone(qname, env);
+    interface_fault_impl->f_qname = axutil_qname_clone(qname, env);
     return AXIS2_SUCCESS;
 }
 
@@ -813,7 +813,7 @@
 woden_interface_fault_set_element_qname(
     void *interface_fault,
     const axutil_env_t *env,
-    axis2_qname_t *qname)
+    axutil_qname_t *qname)
 {
     woden_interface_fault_impl_t *interface_fault_impl = NULL;
     axutil_hash_t *super = NULL;
@@ -826,15 +826,15 @@
 
     if (!interface_fault_impl->f_element_qname)
     {
-        axis2_qname_free(interface_fault_impl->f_element_qname, env);
+        axutil_qname_free(interface_fault_impl->f_element_qname, env);
     }
-    interface_fault_impl->f_element_qname = axis2_qname_clone(qname, env);
+    interface_fault_impl->f_element_qname = axutil_qname_clone(qname, env);
 
 
     return AXIS2_SUCCESS;
 }
 
-axis2_qname_t *AXIS2_CALL
+axutil_qname_t *AXIS2_CALL
 woden_interface_fault_get_element_qname(
     void *interface_fault,
     const axutil_env_t *env)

Modified: webservices/axis2/trunk/c/woden/src/wsdl20/woden_interface_fault_ref.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/wsdl20/woden_interface_fault_ref.c?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/woden/src/wsdl20/woden_interface_fault_ref.c (original)
+++ webservices/axis2/trunk/c/woden/src/wsdl20/woden_interface_fault_ref.c Fri Mar 30 12:24:00 2007
@@ -42,7 +42,7 @@
     void *f_interface_fault;
     void *f_msg_label;
     void *f_direction;
-    axis2_qname_t *f_ref;
+    axutil_qname_t *f_ref;
 };
 
 #define INTF_TO_IMPL(interface_fault_ref) ((woden_interface_fault_ref_impl_t *) interface_fault_ref)
@@ -97,9 +97,9 @@
 woden_interface_fault_ref_set_ref(
     void *interface_fault_ref,
     const axutil_env_t *env,
-    axis2_qname_t *fault_qname);
+    axutil_qname_t *fault_qname);
 
-axis2_qname_t *AXIS2_CALL
+axutil_qname_t *AXIS2_CALL
 woden_interface_fault_ref_get_ref(
     void *interface_fault_ref,
     const axutil_env_t *env);
@@ -643,7 +643,7 @@
 
     if (interface_fault_ref_impl->f_ref)
     {
-        axis2_qname_free(interface_fault_ref_impl->f_ref, env);
+        axutil_qname_free(interface_fault_ref_impl->f_ref, env);
         interface_fault_ref_impl->f_ref = NULL;
     }
 
@@ -841,7 +841,7 @@
 woden_interface_fault_ref_set_ref(
     void *interface_fault_ref,
     const axutil_env_t *env,
-    axis2_qname_t *fault_qname)
+    axutil_qname_t *fault_qname)
 {
     woden_interface_fault_ref_impl_t *interface_fault_ref_impl = NULL;
     axutil_hash_t *super = NULL;
@@ -854,13 +854,13 @@
 
     if (interface_fault_ref_impl->f_ref)
     {
-        axis2_qname_free(interface_fault_ref_impl->f_ref, env);
+        axutil_qname_free(interface_fault_ref_impl->f_ref, env);
     }
-    interface_fault_ref_impl->f_ref = axis2_qname_clone(fault_qname, env);
+    interface_fault_ref_impl->f_ref = axutil_qname_clone(fault_qname, env);
     return AXIS2_SUCCESS;
 }
 
-axis2_qname_t *AXIS2_CALL
+axutil_qname_t *AXIS2_CALL
 woden_interface_fault_ref_get_ref(
     void *interface_fault_ref,
     const axutil_env_t *env)

Modified: webservices/axis2/trunk/c/woden/src/wsdl20/woden_interface_msg_ref.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/wsdl20/woden_interface_msg_ref.c?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/woden/src/wsdl20/woden_interface_msg_ref.c (original)
+++ webservices/axis2/trunk/c/woden/src/wsdl20/woden_interface_msg_ref.c Fri Mar 30 12:24:00 2007
@@ -45,7 +45,7 @@
     void *f_direction;
     axis2_char_t *f_msg_content_model;
     void *f_element_decl;
-    axis2_qname_t *f_element_qname;
+    axutil_qname_t *f_element_qname;
     void *f_types;
 };
 
@@ -127,9 +127,9 @@
 woden_interface_msg_ref_set_element_qname(
     void *interface_msg_ref,
     const axutil_env_t *env,
-    axis2_qname_t *element);
+    axutil_qname_t *element);
 
-axis2_qname_t *AXIS2_CALL
+axutil_qname_t *AXIS2_CALL
 woden_interface_msg_ref_get_element_qname(
     void *interface_msg_ref,
     const axutil_env_t *env);
@@ -697,7 +697,7 @@
 
     if (interface_msg_ref_impl->f_element_qname)
     {
-        axis2_qname_free(interface_msg_ref_impl->f_element_qname, env);
+        axutil_qname_free(interface_msg_ref_impl->f_element_qname, env);
         interface_msg_ref_impl->f_element_qname = NULL;
     }
 
@@ -1012,7 +1012,7 @@
 woden_interface_msg_ref_set_element_qname(
     void *interface_msg_ref,
     const axutil_env_t *env,
-    axis2_qname_t *element)
+    axutil_qname_t *element)
 {
     woden_interface_msg_ref_impl_t *interface_msg_ref_impl = NULL;
     axutil_hash_t *super = NULL;
@@ -1025,13 +1025,13 @@
 
     if (interface_msg_ref_impl->f_element_qname)
     {
-        axis2_qname_free(interface_msg_ref_impl->f_element_qname, env);
+        axutil_qname_free(interface_msg_ref_impl->f_element_qname, env);
     }
-    interface_msg_ref_impl->f_element_qname = axis2_qname_clone(element, env);
+    interface_msg_ref_impl->f_element_qname = axutil_qname_clone(element, env);
     return AXIS2_SUCCESS;
 }
 
-axis2_qname_t *AXIS2_CALL
+axutil_qname_t *AXIS2_CALL
 woden_interface_msg_ref_get_element_qname(
     void *interface_msg_ref,
     const axutil_env_t *env)

Modified: webservices/axis2/trunk/c/woden/src/wsdl20/woden_svc.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/wsdl20/woden_svc.c?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/woden/src/wsdl20/woden_svc.c (original)
+++ webservices/axis2/trunk/c/woden/src/wsdl20/woden_svc.c Fri Mar 30 12:24:00 2007
@@ -36,8 +36,8 @@
     woden_configurable_t *configurable;
     axutil_hash_t *super;
     axutil_hash_t *methods;
-    axis2_qname_t *f_qname;
-    axis2_qname_t *f_interface_qname;
+    axutil_qname_t *f_qname;
+    axutil_qname_t *f_interface_qname;
     void *f_interface;
     axutil_array_list_t *f_endpoints;
 };
@@ -67,7 +67,7 @@
  *  Service interface methods (the WSDL Component model)
  * ************************************************************/
 
-axis2_qname_t *AXIS2_CALL
+axutil_qname_t *AXIS2_CALL
 woden_svc_get_qname(
     void *svc,
     const axutil_env_t *env);
@@ -89,15 +89,15 @@
 woden_svc_set_qname(
     void *svc,
     const axutil_env_t *env,
-    axis2_qname_t *qname);
+    axutil_qname_t *qname);
 
 axis2_status_t AXIS2_CALL
 woden_svc_set_interface_qname(
     void *svc,
     const axutil_env_t *env,
-    axis2_qname_t *interface_qname);
+    axutil_qname_t *interface_qname);
 
-axis2_qname_t *AXIS2_CALL
+axutil_qname_t *AXIS2_CALL
 woden_svc_get_interface_qname(
     void *svc,
     const axutil_env_t *env);
@@ -609,13 +609,13 @@
 
     if (svc_impl->f_qname)
     {
-        axis2_qname_free(svc_impl->f_qname, env);
+        axutil_qname_free(svc_impl->f_qname, env);
         svc_impl->f_qname = NULL;
     }
 
     if (svc_impl->f_interface_qname)
     {
-        axis2_qname_free(svc_impl->f_interface_qname, env);
+        axutil_qname_free(svc_impl->f_interface_qname, env);
         svc_impl->f_interface_qname = NULL;
     }
 
@@ -756,7 +756,7 @@
  *  Service interface methods (the WSDL Component model)
  * ************************************************************/
 
-axis2_qname_t *AXIS2_CALL
+axutil_qname_t *AXIS2_CALL
 woden_svc_get_qname(
     void *svc,
     const axutil_env_t *env)
@@ -811,7 +811,7 @@
 woden_svc_set_qname(
     void *svc,
     const axutil_env_t *env,
-    axis2_qname_t *qname)
+    axutil_qname_t *qname)
 {
     woden_svc_impl_t *svc_impl = NULL;
     axutil_hash_t *super = NULL;
@@ -823,9 +823,9 @@
 
     if (svc_impl->f_qname)
     {
-        axis2_qname_free(svc_impl->f_qname, env);
+        axutil_qname_free(svc_impl->f_qname, env);
     }
-    svc_impl->f_qname = axis2_qname_clone(qname, env);
+    svc_impl->f_qname = axutil_qname_clone(qname, env);
     return AXIS2_SUCCESS;
 }
 
@@ -833,7 +833,7 @@
 woden_svc_set_interface_qname(
     void *svc,
     const axutil_env_t *env,
-    axis2_qname_t *interface_qname)
+    axutil_qname_t *interface_qname)
 {
     woden_svc_impl_t *svc_impl = NULL;
     axutil_hash_t *super = NULL;
@@ -845,14 +845,14 @@
 
     if (svc_impl->f_interface_qname)
     {
-        axis2_qname_free(svc_impl->f_interface_qname, env);
+        axutil_qname_free(svc_impl->f_interface_qname, env);
     }
 
-    svc_impl->f_interface_qname = axis2_qname_clone(interface_qname, env);
+    svc_impl->f_interface_qname = axutil_qname_clone(interface_qname, env);
     return AXIS2_SUCCESS;
 }
 
-axis2_qname_t *AXIS2_CALL
+axutil_qname_t *AXIS2_CALL
 woden_svc_get_interface_qname(
     void *svc,
     const axutil_env_t *env)

Modified: webservices/axis2/trunk/c/woden/src/xml/woden_bool_attr.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/xml/woden_bool_attr.c?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/woden/src/xml/woden_bool_attr.c (original)
+++ webservices/axis2/trunk/c/woden/src/xml/woden_bool_attr.c Fri Mar 30 12:24:00 2007
@@ -115,7 +115,7 @@
     const axutil_env_t *env,
     axiom_element_t *owner_el,
     axiom_node_t *owner_node,
-    axis2_qname_t *attr_type,
+    axutil_qname_t *attr_type,
     axis2_char_t *attr_value)
 {
     woden_bool_attr_impl_t *bool_attr_impl = NULL;
@@ -233,7 +233,7 @@
         axis2_char_t *attr_value)
 {
     woden_bool_attr_impl_t *bool_attr_impl = NULL;
-    axis2_qname_t *qn = NULL;
+    axutil_qname_t *qn = NULL;
 
     AXIS2_ENV_CHECK(env, NULL);
     bool_attr_impl = INTF_TO_IMPL(bool_attr);

Modified: webservices/axis2/trunk/c/woden/src/xml/woden_qname_attr.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/xml/woden_qname_attr.c?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/woden/src/xml/woden_qname_attr.c (original)
+++ webservices/axis2/trunk/c/woden/src/xml/woden_qname_attr.c Fri Mar 30 12:24:00 2007
@@ -52,7 +52,7 @@
     void *qname_attr,
     const axutil_env_t *env);
 
-axis2_qname_t *AXIS2_CALL
+axutil_qname_t *AXIS2_CALL
 woden_qname_attr_get_qname(
     void *qname_attr,
     const axutil_env_t *env);
@@ -74,7 +74,7 @@
     const axutil_env_t *env,
     axiom_element_t *owner_el,
     axiom_node_t *owner_node,
-    axis2_qname_t *attr_type,
+    axutil_qname_t *attr_type,
     axis2_char_t *attr_value)
 {
     woden_qname_attr_impl_t *qname_attr_impl = NULL;
@@ -208,7 +208,7 @@
     return AXIS2_SUCCESS;
 }
 
-axis2_qname_t *AXIS2_CALL
+axutil_qname_t *AXIS2_CALL
 woden_qname_attr_get_qname(
     void *qname_attr,
     const axutil_env_t *env)
@@ -217,7 +217,7 @@
 
     AXIS2_ENV_CHECK(env, NULL);
     qname_attr_impl = INTF_TO_IMPL(qname_attr);
-    return (axis2_qname_t *) WODEN_XML_ATTR_GET_CONTENT(
+    return (axutil_qname_t *) WODEN_XML_ATTR_GET_CONTENT(
                 qname_attr_impl->xml_attr, env);
 }
 
@@ -230,7 +230,7 @@
     axis2_char_t *attr_value)
 {
     woden_qname_attr_impl_t *qname_attr_impl = NULL;
-    axis2_qname_t *qn = NULL;
+    axutil_qname_t *qn = NULL;
 
     AXIS2_ENV_CHECK(env, NULL);
     qname_attr_impl = INTF_TO_IMPL(qname_attr);

Modified: webservices/axis2/trunk/c/woden/src/xml/woden_qname_list_attr.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/xml/woden_qname_list_attr.c?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/woden/src/xml/woden_qname_list_attr.c (original)
+++ webservices/axis2/trunk/c/woden/src/xml/woden_qname_list_attr.c Fri Mar 30 12:24:00 2007
@@ -74,7 +74,7 @@
     const axutil_env_t *env,
     axiom_element_t *owner_el,
     axiom_node_t *owner_node,
-    axis2_qname_t *attr_type,
+    axutil_qname_t *attr_type,
     axis2_char_t *attr_value)
 {
     woden_qname_list_attr_impl_t *qname_list_attr_impl = NULL;
@@ -230,7 +230,7 @@
     axis2_char_t *attr_value)
 {
     woden_qname_list_attr_impl_t *qname_list_attr_impl = NULL;
-    axis2_qname_t *qn = NULL;
+    axutil_qname_t *qn = NULL;
 
     AXIS2_ENV_CHECK(env, NULL);
     qname_list_attr_impl = INTF_TO_IMPL(qname_list_attr);

Modified: webservices/axis2/trunk/c/woden/src/xml/woden_qname_list_or_token_any_attr.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/xml/woden_qname_list_or_token_any_attr.c?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/woden/src/xml/woden_qname_list_or_token_any_attr.c (original)
+++ webservices/axis2/trunk/c/woden/src/xml/woden_qname_list_or_token_any_attr.c Fri Mar 30 12:24:00 2007
@@ -92,7 +92,7 @@
     const axutil_env_t *env,
     axiom_element_t *owner_el,
     axiom_node_t *owner_node,
-    axis2_qname_t *attr_type,
+    axutil_qname_t *attr_type,
     axis2_char_t *attr_value)
 {
     woden_qname_list_or_token_any_attr_impl_t *

Modified: webservices/axis2/trunk/c/woden/src/xml/woden_qname_or_token_any_attr.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/xml/woden_qname_or_token_any_attr.c?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/woden/src/xml/woden_qname_or_token_any_attr.c (original)
+++ webservices/axis2/trunk/c/woden/src/xml/woden_qname_or_token_any_attr.c Fri Mar 30 12:24:00 2007
@@ -64,7 +64,7 @@
     void *token_attr,
     const axutil_env_t *env);
 
-axis2_qname_t *AXIS2_CALL
+axutil_qname_t *AXIS2_CALL
 woden_qname_or_token_any_attr_get_qname(
     void *token_attr,
     const axutil_env_t *env);
@@ -90,7 +90,7 @@
 woden_qname_or_token_any_attr_create(const axutil_env_t *env,
         axiom_element_t *owner_el,
         axiom_node_t *owner_node,
-        axis2_qname_t *attr_type,
+        axutil_qname_t *attr_type,
         axis2_char_t *attr_value)
 {
     woden_qname_or_token_any_attr_impl_t *
@@ -304,7 +304,7 @@
     }
 }
 
-axis2_qname_t *AXIS2_CALL
+axutil_qname_t *AXIS2_CALL
 woden_qname_or_token_any_attr_get_qname(
     void *token_attr,
     const axutil_env_t *env)
@@ -317,7 +317,7 @@
 
     if (AXIS2_TRUE == woden_qname_or_token_any_attr_is_qname(token_attr,
             env))
-        return (axis2_qname_t *) WODEN_XML_ATTR_GET_CONTENT(
+        return (axutil_qname_t *) WODEN_XML_ATTR_GET_CONTENT(
                     token_attr_impl->xml_attr, env);
     else
         return NULL;
@@ -356,7 +356,7 @@
 {
     woden_qname_or_token_any_attr_impl_t *
     token_attr_impl = NULL;
-    axis2_qname_t *qn = NULL;
+    axutil_qname_t *qn = NULL;
 
     AXIS2_ENV_CHECK(env, NULL);
     token_attr_impl = INTF_TO_IMPL(token_attr);

Modified: webservices/axis2/trunk/c/woden/src/xml/woden_string_attr.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/xml/woden_string_attr.c?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/woden/src/xml/woden_string_attr.c (original)
+++ webservices/axis2/trunk/c/woden/src/xml/woden_string_attr.c Fri Mar 30 12:24:00 2007
@@ -75,7 +75,7 @@
     const axutil_env_t *env,
     axiom_element_t *owner_el,
     axiom_node_t *owner_node,
-    axis2_qname_t *attr_type,
+    axutil_qname_t *attr_type,
     axis2_char_t *attr_value)
 {
     woden_string_attr_impl_t *string_attr_impl = NULL;

Modified: webservices/axis2/trunk/c/woden/src/xml/woden_uri_attr.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/xml/woden_uri_attr.c?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/woden/src/xml/woden_uri_attr.c (original)
+++ webservices/axis2/trunk/c/woden/src/xml/woden_uri_attr.c Fri Mar 30 12:24:00 2007
@@ -75,7 +75,7 @@
     const axutil_env_t *env,
     axiom_element_t *owner_el,
     axiom_node_t *owner_node,
-    axis2_qname_t *attr_type,
+    axutil_qname_t *attr_type,
     axis2_char_t *attr_value)
 {
     woden_uri_attr_impl_t *uri_attr_impl = NULL;

Modified: webservices/axis2/trunk/c/woden/src/xml/woden_xml_attr.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/xml/woden_xml_attr.c?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/woden/src/xml/woden_xml_attr.c (original)
+++ webservices/axis2/trunk/c/woden/src/xml/woden_xml_attr.c Fri Mar 30 12:24:00 2007
@@ -30,7 +30,7 @@
 struct woden_xml_attr_impl
 {
     woden_xml_attr_t xml_attr;
-    axis2_qname_t *f_attr_type;
+    axutil_qname_t *f_attr_type;
     axutil_generic_obj_t *f_content;
     axis2_char_t *f_external_form;
     axis2_bool_t f_valid;
@@ -49,10 +49,10 @@
     const axutil_env_t *env,
     axiom_element_t *owner_el,
     axiom_node_t *owner_node,
-    axis2_qname_t *attr_type,
+    axutil_qname_t *attr_type,
     axis2_char_t *attr_value);
 
-axis2_qname_t *AXIS2_CALL
+axutil_qname_t *AXIS2_CALL
 woden_xml_attr_get_attribute_type(
     void *xml_attr,
     const axutil_env_t *env);
@@ -83,7 +83,7 @@
     const axutil_env_t *env,
     axiom_element_t *owner_el,
     axiom_node_t *owner_node,
-    axis2_qname_t *attr_type,
+    axutil_qname_t *attr_type,
     axis2_char_t *attr_value)
 {
     woden_xml_attr_impl_t *xml_attr_impl = NULL;
@@ -128,7 +128,7 @@
 
     if (xml_attr_impl->f_attr_type)
     {
-        axis2_qname_free(xml_attr_impl->f_attr_type, env);
+        axutil_qname_free(xml_attr_impl->f_attr_type, env);
         xml_attr_impl->f_attr_type = NULL;
     }
 
@@ -189,7 +189,7 @@
     const axutil_env_t *env,
     axiom_element_t *owner_el,
     axiom_node_t *owner_node,
-    axis2_qname_t *attr_type,
+    axutil_qname_t *attr_type,
     axis2_char_t *attr_value)
 {
     woden_xml_attr_impl_t *xml_attr_impl = NULL;
@@ -203,13 +203,13 @@
 
     if (xml_attr_impl->f_attr_type)
     {
-        axis2_qname_free(xml_attr_impl->f_attr_type, env);
+        axutil_qname_free(xml_attr_impl->f_attr_type, env);
         xml_attr_impl->f_attr_type = NULL;
     }
-    xml_attr_impl->f_attr_type = axis2_qname_clone(attr_type, env);
+    xml_attr_impl->f_attr_type = axutil_qname_clone(attr_type, env);
     if (xml_attr_impl->f_attr_type)
     {
-        axis2_qname_free(xml_attr_impl->f_attr_type, env);
+        axutil_qname_free(xml_attr_impl->f_attr_type, env);
         xml_attr_impl->f_attr_type = NULL;
     }
     xml_attr_impl->f_external_form = axis2_strdup(env, attr_value);
@@ -221,7 +221,7 @@
     return AXIS2_SUCCESS;
 }
 
-axis2_qname_t *AXIS2_CALL
+axutil_qname_t *AXIS2_CALL
 woden_xml_attr_get_attribute_type(
     void *xml_attr,
     const axutil_env_t *env)

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema.h?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema.h Fri Mar 30 12:24:00 2007
@@ -139,13 +139,13 @@
     get_element_by_qname)(
             void *schema,
             const axutil_env_t *env,
-            const axis2_qname_t *qname); 
+            const axutil_qname_t *qname); 
 
     struct xml_schema_type *(AXIS2_CALL *
     get_type_by_qname)(
             void *schema,
             const axutil_env_t *env,
-            axis2_qname_t *qname); 
+            axutil_qname_t *qname); 
 
     struct xml_schema_derivation_method *(AXIS2_CALL *
     get_final_default)(

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_attribute.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_attribute.h?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_attribute.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_attribute.h Fri Mar 30 12:24:00 2007
@@ -26,7 +26,7 @@
  *          World Wide Web Consortium (W3C) any element.
  *
  */
-#include <axis2_qname.h>
+#include <axutil_qname.h>
 #include <xml_schema_particle.h>
 #include <xml_schema_form.h>
 #include <xml_schema_use.h>
@@ -108,14 +108,14 @@
                      const axutil_env_t *env,
                      xml_schema_form_t *schema_form);
                      
-    axis2_qname_t* (AXIS2_CALL *
+    axutil_qname_t* (AXIS2_CALL *
     get_qname)(void *attr,
                const axutil_env_t *env);
                
     axis2_status_t (AXIS2_CALL *
     set_qname)(void *attr,
                const axutil_env_t *env,
-               axis2_qname_t *qualified_name);
+               axutil_qname_t *qualified_name);
                
     axis2_char_t* (AXIS2_CALL *
     get_name)(void *attr,
@@ -126,14 +126,14 @@
               const axutil_env_t *env,
               axis2_char_t *name);
               
-    axis2_qname_t* (AXIS2_CALL *
+    axutil_qname_t* (AXIS2_CALL *
     get_ref_name)(void *attr,
                   const axutil_env_t *env);
                                               
     axis2_status_t (AXIS2_CALL *
     set_ref_name)(void *attr,
                   const axutil_env_t *env,
-                  axis2_qname_t *ref_name);
+                  axutil_qname_t *ref_name);
                   
     xml_schema_simple_type_t* (AXIS2_CALL *
     get_schema_type)(void *attr,
@@ -144,7 +144,7 @@
                      const axutil_env_t *env,
                      xml_schema_simple_type_t* sch_type);                     
                      
-    axis2_qname_t* (AXIS2_CALL *
+    axutil_qname_t* (AXIS2_CALL *
     get_schema_type_name)(void *attr,
                           const axutil_env_t *env);
                           
@@ -152,7 +152,7 @@
     axis2_status_t (AXIS2_CALL *
     set_schema_type_name)(void *attr,
                           const axutil_env_t *env,
-                          axis2_qname_t *sch_type_name);
+                          axutil_qname_t *sch_type_name);
                           
     xml_schema_use_t* (AXIS2_CALL *
     get_use)(void *attr,

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_attribute_group.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_attribute_group.h?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_attribute_group.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_attribute_group.h Fri Mar 30 12:24:00 2007
@@ -26,7 +26,7 @@
  *          World Wide Web Consortium (W3C) any element.
  *
  */
-#include <axis2_qname.h>
+#include <axutil_qname.h>
 #include <xml_schema_particle.h>
 #include <xml_schema_obj_collection.h>
 #include <xml_schema_any_attribute.h>

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_attribute_group_ref.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_attribute_group_ref.h?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_attribute_group_ref.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_attribute_group_ref.h Fri Mar 30 12:24:00 2007
@@ -26,7 +26,7 @@
  *          World Wide Web Consortium (W3C) any element.
  *
  */
-#include <axis2_qname.h>
+#include <axutil_qname.h>
 #include <xml_schema_particle.h>
 #include <xml_schema_obj_collection.h>
 #include <xml_schema_any_attribute.h>
@@ -75,14 +75,14 @@
             const axutil_env_t *env);
     
 
-    axis2_qname_t* (AXIS2_CALL *
+    axutil_qname_t* (AXIS2_CALL *
     get_ref_qname)(void *grp_ref,
               const axutil_env_t *env);
               
     axis2_status_t (AXIS2_CALL *
     set_ref_qname)(void *grp_ref,
               const axutil_env_t *env,
-              axis2_qname_t *ref_name);
+              axutil_qname_t *ref_name);
               
 };
 

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_collection.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_collection.h?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_collection.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_collection.h Fri Mar 30 12:24:00 2007
@@ -27,12 +27,12 @@
 #include <axutil_allocator.h>
 #include <axutil_env.h>
 #include <axutil_error.h>
-#include <axis2_string.h>
+#include <axutil_string.h>
 #include <axis2_utils.h>
 
 #include <axutil_array_list.h>
 #include <axutil_hash.h>
-#include <axis2_qname.h>
+#include <axutil_qname.h>
 #include <xml_schema_obj.h>
 #include <axiom_xml_reader.h>
 #include <axiom_document.h>
@@ -123,20 +123,20 @@
     get_element_by_qname)(
             xml_schema_collection_t* collection,
             const axutil_env_t *env,
-            axis2_qname_t *qname);
+            axutil_qname_t *qname);
 
     struct xml_schema_type *(AXIS2_CALL *
     get_type_by_qname)(
             xml_schema_collection_t* collection,
             const axutil_env_t *env,
-            axis2_qname_t *schema_type_qname);
+            axutil_qname_t *schema_type_qname);
 
 
     axis2_status_t (AXIS2_CALL *
     add_unresolved_type)(
             xml_schema_collection_t* collection,
             const axutil_env_t *env,
-            axis2_qname_t *qtype, 
+            axutil_qname_t *qtype, 
             void *receiver); 
             
 
@@ -144,7 +144,7 @@
     resolve_type)(
             xml_schema_collection_t* collection,
             const axutil_env_t *env,
-            axis2_qname_t *type_qname, 
+            axutil_qname_t *type_qname, 
             struct xml_schema_type *type); 
             
 

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_complex_content_extension.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_complex_content_extension.h?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_complex_content_extension.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_complex_content_extension.h Fri Mar 30 12:24:00 2007
@@ -27,7 +27,7 @@
 #include <xml_schema_any_attribute.h>
 #include <xml_schema_particle.h>
 #include <axutil_hash.h>
-#include <axis2_qname.h>
+#include <axutil_qname.h>
 /** @defgroup xml_schema_complex_content_extension 
   * @ingroup xml_schema
   * @{
@@ -80,7 +80,7 @@
             void *cmp_content_ext,
             const axutil_env_t *env);
             
-    axis2_qname_t* (AXIS2_CALL*
+    axutil_qname_t* (AXIS2_CALL*
     get_base_type_name)(
             void *cmp_content_ext,
             const axutil_env_t *env);
@@ -89,7 +89,7 @@
     set_base_type_name)(
             void *cmp_content_ext,
             const axutil_env_t *env,
-            axis2_qname_t *qname);
+            axutil_qname_t *qname);
             
     xml_schema_particle_t* (AXIS2_CALL *
     get_particle)(

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_complex_content_restriction.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_complex_content_restriction.h?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_complex_content_restriction.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_complex_content_restriction.h Fri Mar 30 12:24:00 2007
@@ -27,7 +27,7 @@
 #include <xml_schema_any_attribute.h>
 #include <xml_schema_simple_type.h>
 #include <axutil_hash.h>
-#include <axis2_qname.h>
+#include <axutil_qname.h>
 
 /** @defgroup xml_schema_complex_content_restriction Xml Schema Group
   * @ingroup xml_schema
@@ -82,7 +82,7 @@
             void *cmp_content_res,
             const axutil_env_t *env);
             
-    axis2_qname_t* (AXIS2_CALL*
+    axutil_qname_t* (AXIS2_CALL*
     get_base_type_name)(
             void *cmp_content_res,
             const axutil_env_t *env);
@@ -91,7 +91,7 @@
     set_base_type_name)(
             void *cmp_content_res,
             const axutil_env_t *env,
-            axis2_qname_t *qname); 
+            axutil_qname_t *qname); 
             
     xml_schema_particle_t* (AXIS2_CALL *
     get_particle)(

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_complex_type.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_complex_type.h?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_complex_type.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_complex_type.h Fri Mar 30 12:24:00 2007
@@ -27,7 +27,7 @@
 #include <xml_schema_annotated.h>
 #include <xml_schema_type.h>
 #include <axutil_hash.h>
-#include <axis2_qname.h>
+#include <axutil_qname.h>
 #include <xml_schema_complex_type.h>
 #include <xml_schema_any_attribute.h>
 #include <xml_schema_obj_collection.h>

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_data_type.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_data_type.h?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_data_type.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_data_type.h Fri Mar 30 12:24:00 2007
@@ -26,7 +26,7 @@
 #include <axutil_allocator.h>
 #include <axutil_env.h>
 #include <axutil_error.h>
-#include <axis2_string.h>
+#include <axutil_string.h>
 #include <axutil_array_list.h>
 #include <axutil_hash.h>
 

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_element.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_element.h?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_element.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_element.h Fri Mar 30 12:24:00 2007
@@ -26,7 +26,7 @@
  */
 
 #include <xml_schema_particle.h>
-#include <axis2_qname.h>
+#include <axutil_qname.h>
 
 /** @defgroup xml_schema_element Xml Schema Element
   * @ingroup xml_schema
@@ -165,7 +165,7 @@
             const axutil_env_t *env,
             axis2_char_t *name);
 
-    axis2_qname_t *(AXIS2_CALL * 
+    axutil_qname_t *(AXIS2_CALL * 
     get_ref_qname)(
             void *element,
             const axutil_env_t *env);
@@ -174,9 +174,9 @@
     set_ref_qname)(
             void *element,
             const axutil_env_t *env,
-            axis2_qname_t *ref_qname);
+            axutil_qname_t *ref_qname);
 
-    axis2_qname_t *(AXIS2_CALL * 
+    axutil_qname_t *(AXIS2_CALL * 
     get_qname)(
             void *element,
             const axutil_env_t *env);
@@ -185,7 +185,7 @@
     set_qname)(
             void *element,
             const axutil_env_t *env,
-            axis2_qname_t *qualified_name); 
+            axutil_qname_t *qualified_name); 
 
     struct xml_schema_type *(AXIS2_CALL *
     get_schema_type)(
@@ -198,7 +198,7 @@
             const axutil_env_t *env,
             void *schema_type);
 
-    axis2_qname_t *(AXIS2_CALL * 
+    axutil_qname_t *(AXIS2_CALL * 
     get_schema_type_qname)(
             void *element,
             const axutil_env_t *env);
@@ -207,9 +207,9 @@
     set_schema_type_qname)(
             void *element,
             const axutil_env_t *env,
-            axis2_qname_t *schema_type_qname);
+            axutil_qname_t *schema_type_qname);
 
-    axis2_qname_t *(AXIS2_CALL * 
+    axutil_qname_t *(AXIS2_CALL * 
     get_substitution_group)(
             void *element,
             const axutil_env_t *env);
@@ -218,7 +218,7 @@
     set_substitution_group)(
             void *element,
             const axutil_env_t *env,
-            axis2_qname_t *substitution_group);
+            axutil_qname_t *substitution_group);
 
     axis2_char_t *(AXIS2_CALL * 
     to_string)(

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_enum.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_enum.h?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_enum.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_enum.h Fri Mar 30 12:24:00 2007
@@ -26,7 +26,7 @@
 #include <axutil_allocator.h>
 #include <axutil_env.h>
 #include <axutil_error.h>
-#include <axis2_string.h>
+#include <axutil_string.h>
 #include <axis2_utils_defines.h>
 #include <axutil_array_list.h>
 #include <axutil_hash.h>

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_group_ref.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_group_ref.h?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_group_ref.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_group_ref.h Fri Mar 30 12:24:00 2007
@@ -29,7 +29,7 @@
 #include <xml_schema_defines.h>
 #include <xml_schema_particle.h>
 #include <axutil_hash.h>
-#include <axis2_qname.h>
+#include <axutil_qname.h>
 
 /** @defgroup_ref xml_schema_group_ref Xml Schema Group Ref
   * @ingroup_ref xml_schema
@@ -65,14 +65,14 @@
     get_base_impl) (void *group_ref,
                     const axutil_env_t *env);
 
-    axis2_qname_t *(AXIS2_CALL *
+    axutil_qname_t *(AXIS2_CALL *
     get_ref_qname)(void *group_ref,
                     const axutil_env_t *env);
     
     axis2_status_t (AXIS2_CALL *
     set_ref_qname)(void *group_ref,
                     const axutil_env_t *env,
-                    axis2_qname_t *ref_qname);
+                    axutil_qname_t *ref_qname);
     
     void *(AXIS2_CALL *
     get_particle)(void *group_ref,

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_identity_constraint.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_identity_constraint.h?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_identity_constraint.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_identity_constraint.h Fri Mar 30 12:24:00 2007
@@ -26,7 +26,7 @@
 
 #include <xml_schema_annotated.h>
 #include <axutil_hash.h>
-#include <axis2_qname.h>
+#include <axutil_qname.h>
 
 /** @defidentity_constraint xml_schema_identity_constraint Xml Schema 
   *  Identity Constraint
@@ -70,14 +70,14 @@
             const axutil_env_t *env);   
         
     /** xml schema keyref method */            
-    axis2_qname_t* (AXIS2_CALL *
+    axutil_qname_t* (AXIS2_CALL *
     get_refer)(void *id_constr,
                const axutil_env_t *env);
 
     /** xml schema keyref method */               
     axis2_status_t (AXIS2_CALL *                                                                    set_refer)(void *id_constr,
                const axutil_env_t *env,
-               axis2_qname_t *refer);
+               axutil_qname_t *refer);
 
     struct xml_schema_obj_collection *(AXIS2_CALL *
     get_fields)(void *id_constr,

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_obj.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_obj.h?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_obj.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_obj.h Fri Mar 30 12:24:00 2007
@@ -36,7 +36,7 @@
 #include <axutil_allocator.h>
 #include <axutil_env.h>
 #include <axutil_error.h>
-#include <axis2_string.h>
+#include <axutil_string.h>
 #include <axis2_utils_defines.h>
 #include <axutil_array_list.h>
 #include <axutil_hash.h>

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_obj_collection.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_obj_collection.h?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_obj_collection.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_obj_collection.h Fri Mar 30 12:24:00 2007
@@ -28,7 +28,7 @@
 #include <axutil_allocator.h>
 #include <axutil_env.h>
 #include <axutil_error.h>
-#include <axis2_string.h>
+#include <axutil_string.h>
 #include <axutil_array_list.h>
 #include <axutil_hash.h>
 #include <xml_schema_obj.h>

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_obj_table.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_obj_table.h?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_content_extension.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_content_extension.h Fri Mar 30 12:24:00 2007
@@ -31,7 +31,7 @@
 #include <xml_schema_obj_collection.h>
 #include <xml_schema_any_attribute.h>
 #include <axutil_hash.h>
-#include <axis2_qname.h>
+#include <axutil_qname.h>
 /** @defgroup xml_schema_simple_content_extension Xml Schema Group
   * @ingroup xml_schema
   * @{
@@ -84,7 +84,7 @@
             void *sim_content_ext,
             const axutil_env_t *env);
             
-    axis2_qname_t* (AXIS2_CALL*
+    axutil_qname_t* (AXIS2_CALL*
     get_base_type_name)(
             void *sim_content_ext,
             const axutil_env_t *env);
@@ -93,7 +93,7 @@
     set_base_type_name)(
             void *sim_content_ext,
             const axutil_env_t *env,
-            axis2_qname_t *qname);
+            axutil_qname_t *qname);
             
 
     

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_content_restriction.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_content_restriction.h?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_content_restriction.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_content_restriction.h Fri Mar 30 12:24:00 2007
@@ -32,7 +32,7 @@
 #include <xml_schema_any_attribute.h>
 #include <xml_schema_simple_type.h>
 #include <axutil_hash.h>
-#include <axis2_qname.h>
+#include <axutil_qname.h>
 
 /** @defgroup xml_schema_simple_content_restriction Xml Schema Group
   * @ingroup xml_schema
@@ -87,7 +87,7 @@
             void *sim_content_res,
             const axutil_env_t *env);
             
-    axis2_qname_t* (AXIS2_CALL*
+    axutil_qname_t* (AXIS2_CALL*
     get_base_type_name)(
             void *sim_content_res,
             const axutil_env_t *env);
@@ -96,7 +96,7 @@
     set_base_type_name)(
             void *sim_content_res,
             const axutil_env_t *env,
-            axis2_qname_t *qname); 
+            axutil_qname_t *qname); 
             
     xml_schema_simple_type_t* (AXIS2_CALL*
     get_base_type)(

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_type.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_type.h?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_type.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_type.h Fri Mar 30 12:24:00 2007
@@ -27,7 +27,7 @@
 #include <xml_schema_annotated.h>
 #include <xml_schema_type.h>
 #include <axutil_hash.h>
-#include <axis2_qname.h>
+#include <axutil_qname.h>
 #include <xml_schema_simple_type_content.h>
 /** @defgroup xml_schema_simple_type Xml Schema Type
   * @ingroup xml_schema

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_type_list.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_type_list.h?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_type_list.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_type_list.h Fri Mar 30 12:24:00 2007
@@ -76,14 +76,14 @@
                    const axutil_env_t *env,
                    xml_schema_simple_type_t *base_type);
     
-    axis2_qname_t* (AXIS2_CALL *
+    axutil_qname_t* (AXIS2_CALL *
     get_item_type_name)(void *simple_type_list,
                 const axutil_env_t *env);
     
     axis2_status_t (AXIS2_CALL *
     set_item_type_name)(void *simple_type_list,
                     const axutil_env_t *env,
-                    axis2_qname_t *qname);
+                    axutil_qname_t *qname);
 };
 
 struct xml_schema_simple_type_list

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_type_restriction.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_type_restriction.h?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_type_restriction.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_type_restriction.h Fri Mar 30 12:24:00 2007
@@ -70,14 +70,14 @@
                     const axutil_env_t *env,
                     xml_schema_simple_type_t *base_type);
     
-    axis2_qname_t* (AXIS2_CALL *
+    axutil_qname_t* (AXIS2_CALL *
     get_base_type_name)(void *simple_type_restriction,
                 const axutil_env_t *env);
     
     axis2_status_t (AXIS2_CALL *
     set_base_type_name)(void *simple_type_restriction,
                     const axutil_env_t *env,
-                    axis2_qname_t *qname);
+                    axutil_qname_t *qname);
                     
     xml_schema_obj_collection_t* (AXIS2_CALL *
     get_facets)(void *simple_type_restriction,

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_type.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_type.h?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_type.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_type.h Fri Mar 30 12:24:00 2007
@@ -26,7 +26,7 @@
 
 #include <xml_schema_annotated.h>
 #include <axutil_hash.h>
-#include <axis2_qname.h>
+#include <axutil_qname.h>
 
 /** @defgroup xml_schema_type Xml Schema Type
   * @ingroup xml_schema
@@ -105,7 +105,7 @@
                         const axutil_env_t *env,
                         axis2_char_t *name); 
 
-    axis2_qname_t *(AXIS2_CALL *
+    axutil_qname_t *(AXIS2_CALL *
     get_qname) (void *type,
                         const axutil_env_t *env);
 



---------------------------------------------------------------------
To unsubscribe, e-mail: axis-cvs-unsubscribe@ws.apache.org
For additional commands, e-mail: axis-cvs-help@ws.apache.org
--- webservices/axis2/trunk/c/xml_schema/include/xml_schema_obj_table.h (original)
+++ webservices/axis2/trunk/c/xml_schema/include/xml_schema_obj_table.h Fri Mar 30 12:24:00 2007
@@ -36,11 +36,11 @@
 #include <axutil_allocator.h>
 #include <axutil_env.h>
 #include <axutil_error.h>
-#include <axis2_string.h>
+#include <axutil_string.h>
 #include <axis2_utils.h>
 #include <axutil_array_list.h>
 #include <axutil_hash.h>
-#include <axis2_qname.h>
+#include <axutil_qname.h>
 #include <xml_schema_obj.h>
 
 #ifdef __cplusplus
@@ -93,7 +93,7 @@
     get_item)(
             xml_schema_obj_table_t *obj_table,
             const axutil_env_t *env,
-            const axis2_qname_t *qname);
+            const axutil_qname_t *qname);
 
     /**
      * Get an array_list containing the qnames which
@@ -123,20 +123,20 @@
      * Checks whether there is a value stored with a qiven qname 
      * @param obj_table pointer to xml_schema_obj_table
      * @param env environment
      * @param qname pointer to axis2_qname_t 
      * @returns AXIS2_TRUE if value exists, AXIS2_FALSE otherwise
      */
     axis2_bool_t (AXIS2_CALL *
     contains)(
             xml_schema_obj_table_t *obj_table,
             const axutil_env_t *env,
-            axis2_qname_t *qname);
+            axutil_qname_t *qname);
 
     axis2_status_t (AXIS2_CALL *
     add) (
             xml_schema_obj_table_t *obj_table,
             const axutil_env_t *env,
-            axis2_qname_t *qname,
+            axutil_qname_t *qname,
             void *value);
           
     axis2_status_t (AXIS2_CALL *
@@ -123,20 +123,20 @@
      * @param obj_table pointer to xml_schema_obj_table
      * @param env environment
-     * @param qname pointer to axis2_qname_t 
+     * @param qname pointer to axutil_qname_t 
      * @returns AXIS2_TRUE if value exists, AXIS2_FALSE otherwise
      */

Modified: webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_content_extension.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/xml_schema/include/xml_schema_simple_content_extension.h?view=diff&rev=524243&r1=524242&r2=524243
==============================================================================